@@ -5,6 +5,8 @@ from pas.plugins.imio.testing import PAS_PLUGINS_IMIO_INTEGRATION_TESTING
 from pas.plugins.imio.tests.utils import MockupUser
 from plone import api
 
+import random
+import string
 import unittest
 
 
@@ -52,7 +54,7 @@ class TestPlugin(unittest.TestCase):
         )
         self.assertEqual(
             self.plugin.enumerateUsers(login="james"),
-            [{"login": "jamesbond", "pluginid": "authentic", "id": u"123456"}],
+            [{"login": "jamesbond", "pluginid": "authentic", "id": "123456"}],
         )
         self.assertEqual(
             self.plugin.enumerateUsers(login="bond"),
@@ -93,3 +95,37 @@ class TestPlugin(unittest.TestCase):
         self.assertEqual(user.id, "12345-67890")
         user = api.user.get(username="imio username")
         self.assertEqual(user.id, "12345-67890")
+
+    def test_keeping_groups(self):
+        # create on user with a group
+        user_id = "123456789"
+        username = "mynewuser"
+        email = "imio@username.be"
+        registration = api.portal.get_tool("portal_registration")
+        chars = string.ascii_letters + string.digits
+        password = "".join(random.choice(chars) for char in range(8))
+        properties = {"email": email, "username": username}
+        registration.addMember(username, password, ("Member",), properties=properties)
+        group = api.group.create("test_group")
+        api.group.add_user(group=group, username=username)
+        groups = api.group.get_groups(username=username)
+        self.assertIn("test_group", [group.id for group in groups])
+        acl_users = api.portal.get_tool("acl_users")
+        source_users = acl_users.source_users
+        self.assertIn(username, [user for user in source_users.listUserIds()])
+        data = {
+            "id": user_id,
+            "username": username,
+            "email": email,
+        }
+
+        # migrate user
+        authomatic_user = User("authentic", **data)
+        mockup_user = MockupUser(self.plugin, authomatic_user)
+        self.plugin.remember_identity(mockup_user)
+
+        source_users = acl_users.source_users
+        self.assertNotIn(username, [user for user in source_users.listUserIds()])
+        self.assertNotIn(user_id, [user for user in source_users.listUserIds()])
+        groups = api.group.get_groups(username=user_id)
+        self.assertIn("test_group", [group.id for group in groups])
